@@ -593,24 +593,7 @@ class Commit(object):
         required_fee_vests = 0
         delegation_fee_hive = Amount(delegation_fee_hive)
         if float(delegation_fee_hive):
-            # creating accounts without delegation requires 30x
-            # account_creation_fee creating account with delegation allows one
-            # to use VESTS to pay the fee where the ratio must satisfy 1 HIVE
-            # in fee == 5 HIVE in delegated VESTS
-
-            delegated_hp_fee_mult = 5
-
-            if float(delegation_fee_hive) < 1:
-                raise ValueError(
-                    "When creating account with delegation, at least "
-                    + "1 HIVE in fee must be paid."
-                )
-
-            # calculate required remaining fee in vests
-            remaining_fee = required_fee_hive - delegation_fee_hive
-            if float(remaining_fee) > 0:
-                required_hp = remaining_fee * delegated_hp_fee_mult
-                required_fee_vests = Converter().hp_to_vests(required_hp) + 1
+            required_fee_vests = Converter().hp_to_vests(float(delegation_fee_hive))
 
         s = {
             "creator": creator,
